
Authors
=======

* Caelan Garrett <caelan@csail.mit.edu> `@caelan <https://github.com/caelan>`_
* Yijiang Huang <yijiangh@mit.edu> `@yijiangh <https://github.com/yijiangh>`_

Acknowledgements
================

We thank the authors for the following models that we use in the unit tests.

- The clamp `c1` URDF model is designed by `@yck011522 <https://github.com/yck011522>`_.
- The dms gripper mesh model is designed by `@stefanaparascho <https://github.com/stefanaparascho>`_.
- The `kuka_kr6_r900` URDF model is from `@ros-industrial/kuka_experimental <https://github.com/ros-industrial/kuka_experimental>`_.
- The `universal_robot` URDF model is from `@ros-industrial/universal_robot <https://github.com/ros-industrial/universal_robot>`_.
